==> carbon-components-react-0.1.8.tgz: package/lib/components/CardActionItem/CardActionItem-test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _CardActionItem = _interopRequireDefault(require("../CardActionItem"));

var _enzyme = require("enzyme");

var _carbonIcons = require("carbon-icons");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import { Icon } from '../Icon';
describe('CardActionItem', function () {
  describe('Renders as expected', function () {
    var props = {
      className: 'extra-class',
      id: 'testId',
      ariaLabel: 'testLabel',
      iconName: {
        iconAdd: _carbonIcons.iconAdd
      },
      description: 'testDescription'
    };
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_CardActionItem.default, props));
    describe('Renders button as expected', function () {
      it('has the expected classes', function () {
        expect(wrapper.hasClass('bx--app-actions__button')).toEqual(true);
      });
      it('renders extra classes passed in via className', function () {
        expect(wrapper.hasClass('extra-class')).toEqual(true);
      });
      it('has id passed in via props', function () {
        expect(wrapper.props().id).toEqual('testId');
      });
      it('has ariaLabel passed in via props', function () {
        expect(wrapper.props()['aria-label']).toEqual('testLabel');
      });
    }); // describe('Renders Icon as expected', () => {
    //   const icon = wrapper.find(Icon);
    //   console.log("HEIGHT: " + icon.height);
    //   it('Icon should have expected class', () => {
    //     expect(icon.hasClass('bx--app-actions__button--icon')).toEqual(true);
    //   });
    //   it('Icon has specified name', () => {
    //     expect(icon.props().name).toEqual('testName');
    //   });
    //   it('Icon has specified description', () => {
    //     expect(icon.props().description).toEqual('testDescription');
    //   });
    // });
  });
});

==> carbon-components-react-0.8.1.tgz: package/lib/components/CardActionItem/CardActionItem-test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _CardActionItem = _interopRequireDefault(require("../CardActionItem"));

var _enzyme = require("enzyme");

var _carbonIcons = require("carbon-icons");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// import { Icon } from '../Icon';
describe('CardActionItem', function () {
  describe('Renders as expected', function () {
    var props = {
      className: 'extra-class',
      id: 'testId',
      ariaLabel: 'testLabel',
      iconName: _carbonIcons.iconAdd,
      description: 'testDescription'
    };
    var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_CardActionItem.default, props));
    describe('Renders button as expected', function () {
      it('has the expected classes', function () {
        expect(wrapper.hasClass('bx--app-actions__button')).toEqual(true);
      });
      it('renders extra classes passed in via className', function () {
        expect(wrapper.hasClass('extra-class')).toEqual(true);
      });
      it('has id passed in via props', function () {
        expect(wrapper.props().id).toEqual('testId');
      });
      it('has ariaLabel passed in via props', function () {
        expect(wrapper.props()['aria-label']).toEqual('testLabel');
      });
    }); // describe('Renders Icon as expected', () => {
    //   const icon = wrapper.find(Icon);
    //   console.log("HEIGHT: " + icon.height);
    //   it('Icon should have expected class', () => {
    //     expect(icon.hasClass('bx--app-actions__button--icon')).toEqual(true);
    //   });
    //   it('Icon has specified name', () => {
    //     expect(icon.props().name).toEqual('testName');
    //   });
    //   it('Icon has specified description', () => {
    //     expect(icon.props().description).toEqual('testDescription');
    //   });
    // });
  });
});
